@@ -1,4 +1,8 @@
+analogsea_sessions <- NULL
+
 .onLoad <- function(libname, pkgname) {
+  analogsea_sessions <<- new.env()
+
   op <- options()
   op.do <- list(
     do.wait_time = 1
